@@ -73,13 +73,14 @@ def ensure_patterns(patterns):
             else:
                 pattern = f"{pattern}*"
         patterns[i] = pattern
-    return set(patterns)
+
+    return patterns
 def define_defaults(
-    allowed_exts: Optional[Set[str]] = None,
-    unallowed_exts: Optional[Set[str]] = None,
-    exclude_types: Optional[Set[str]] = None,
-    exclude_dirs: Optional[List[str]] = None,
-    exclude_patterns: Optional[List[str]] = None,
+    allowed_exts: Optional[Set[str]] = False,
+    unallowed_exts: Optional[Set[str]] = False,
+    exclude_types: Optional[Set[str]] = False,
+    exclude_dirs: Optional[List[str]] = False,
+    exclude_patterns: Optional[List[str]] = False,
     add = False
     ):
     allowed_exts=ensure_exts(allowed_exts)
